diff -urN ./src/ircd.c ../ircd-hybrid-gate/src/ircd.c
--- ./src/ircd.c	Tue May 13 08:32:19 2003
+++ ../ircd-hybrid-gate/src/ircd.c	Thu May 15 00:07:03 2003
@@ -29,6 +29,7 @@
 # include starlet
 #endif
 
+#include <pwd.h>
 #include "tools.h"
 #include "ircd.h"
 #include "channel.h"
@@ -98,6 +99,9 @@
 static unsigned long       initialVMTop = 0;   /* top of virtual memory at init */
 const char * logFileName = LPATH;
 const char * pidFileName = PPATH;
+const char * u_user = NULL;
+
+struct passwd *pentry;
 
 char**  myargv;
 int     dorehash   = 0;
@@ -256,6 +260,8 @@
    STRING, "File to use for ircd.log"},
   {"pidfile",    &pidFileName,
    STRING, "File to use for process ID"},
+  {"user",       &u_user, 
+   STRING, "Run ircd daemon as user user_name"},
   {"foreground", &server_state.foreground, 
    YESNO, "Run in foreground (don't detach)"},
   {"version",    &printVersion, 
@@ -508,15 +514,6 @@
 int
 main(int argc, char *argv[])
 {
-  /* Check to see if the user is running
-   * us as root, which is a nono
-   */
-  if (geteuid() == 0)
-  {
-    fprintf(stderr, "Don't run ircd as root!!!\n");
-    return(-1);
-  }
-
   /*
    * save server boot time right away, so getrusage works correctly
    */
@@ -561,16 +558,48 @@
 
   parseargs(&argc, &argv, myopts);
 
-  if (printVersion)
+  if (u_user)
   {
-    printf("ircd: version %s\n", ircd_version);
-    exit(EXIT_SUCCESS);
+    pentry = getpwnam(u_user);
+
+    if (!pentry)
+    {
+      fprintf(stderr, "User not found %s\n", u_user);
+      return(-1);
+    }
+
+    if (chdir(ConfigFileEntry.dpath))
+    {
+      perror("chdir");
+      exit(EXIT_FAILURE);
+    }
+
+    if (setregid (pentry->pw_gid, pentry->pw_gid))
+    {
+      perror("setregid");
+      exit(EXIT_FAILURE);
+    }
+
+    if (setreuid (pentry->pw_uid, pentry->pw_uid))
+    {
+      perror("setreuid");
+      exit(EXIT_FAILURE);
+    }
+  }
+
+  /* Check to see if the user is running
+   * us as root, which is a nono
+   */
+  if (geteuid() == 0)
+  {
+    fprintf(stderr, "Don't run ircd as root!!!\n");
+    return(-1);
   }
 
-  if (chdir(ConfigFileEntry.dpath))
+  if (printVersion)
   {
-    perror("chdir");
-    exit(EXIT_FAILURE);
+    printf("ircd: version %s\n", ircd_version);
+    exit(EXIT_SUCCESS);
   }
 
 #ifdef __CYGWIN__
